@@ -24,6 +24,7 @@ else:
     from typing_extensions import TypeAlias
 
 from fileformats.core.typing import Self
+from fileformats.core.converter_helpers import SubtypeVar
 from fileformats.core.utils import _excluded_subpackages
 
 from .classifier import Classifier
@@ -260,6 +261,10 @@ class FileSet(DataType):
         "A common parent directory for all the top-level paths in the file-set"
         return Path(os.path.commonpath([p.parent for p in self.fspaths]))
 
+    @property
+    def parents(self) -> ty.Sequence[Path]:
+        return [self.parent] + list(self.parent.parents)
+
     @property
     def relative_fspaths(self) -> ty.Iterator[Path]:
         "Paths for all top-level paths in the file-set relative to the common parent directory"
@@ -670,8 +675,6 @@ class FileSet(DataType):
 
         Parameters
         ----------
-        include_generic: bool
-            If True, only consider parent classes in the same namespace for conversion.
         union_sort_key : callable[[DataType], Any], optional
             A function used to sort the union of types. Defaults to sorting by the type name.
 
@@ -683,9 +686,13 @@ class FileSet(DataType):
 
         datatypes: ty.List[ty.Type[DataType]] = [cls]
         cls._import_extras_module()
-        exclude_subpackages = copy(_excluded_subpackages)
-        exclude_subpackages.discard(cls.namespace)
-        for subcls in FileSet.subclasses(exclude=exclude_subpackages):
+        if cls.namespace == "generic":
+            subclasses = [cls]
+        else:
+            exclude_subpackages = copy(_excluded_subpackages)
+            exclude_subpackages.discard(cls.namespace)
+            subclasses = list(FileSet.subclasses(exclude=exclude_subpackages))
+        for subcls in subclasses:
             if issubclass(subcls, cls):
                 subcls._import_extras_module()
                 datatypes.extend(subcls.get_converters_dict().keys())
@@ -698,6 +705,8 @@ class FileSet(DataType):
             if inspect.isabstract(datatype):
                 for subclass in datatype.subclasses():
                     add_concrete(subclass)
+            elif issubclass(datatype, SubtypeVar):
+                concrete_datatypes.add(datatype.bound)
             else:
                 concrete_datatypes.add(datatype)
 
